Package: sits
Type: Package
Version: 1.5.4
Title: Satellite Image Time Series Analysis for Earth Observation Data
        Cubes
Authors@R: c(person('Rolf', 'Simoes', role = c('aut'), email = 'rolfsimoes@gmail.com'),
             person('Gilberto', 'Camara', role = c('aut', 'cre', 'ths'), email = 'gilberto.camara.inpe@gmail.com'),
             person('Felipe', 'Souza', role = c('aut'), email = 'felipe.carvalho@inpe.br'),
             person('Felipe', 'Carlos', role = c('aut'), email = "efelipecarlos@gmail.com"),
             person('Lorena', 'Santos', role = c('ctb'), email = 'lorena.santos@inpe.br'),
             person('Charlotte', 'Pelletier', role = c('ctb'), email = 'charlotte.pelletier@univ-ubs.fr'),
             person('Estefania', 'Pizarro', role = c('ctb'), email = 'eapizarroa@ine.gob.cl'),
             person('Karine', 'Ferreira', role = c('ctb', 'ths'), email = 'karine.ferreira@inpe.br'),
             person('Alber', 'Sanchez', role = c('ctb'), email = 'alber.ipia@inpe.br'),
             person('Alexandre', 'Assuncao', role = c('ctb'), email = 'alexcarssuncao@gmail.com'),
             person('Daniel', 'Falbel', role = c('ctb'), email = 'dfalbel@gmail.com'),
             person('Gilberto', 'Queiroz', role = c('ctb'), email = 'gilberto.queiroz@inpe.br'),
             person('Johannes', 'Reiche', role = c('ctb'), email = 'johannes.reiche@wur.nl'),
             person('Pedro', 'Andrade', role = c('ctb'), email = 'pedro.andrade@inpe.br'),
             person('Pedro', 'Brito', role = c('ctb'), email = 'pedro_brito1997@hotmail.com'),
             person('Renato', 'Assuncao', role = c('ctb'), email = 'assuncaoest@gmail.com'),
             person('Ricardo', 'Cartaxo', role = c('ctb'), email = 'rcartaxoms@gmail.com')
             )
Maintainer: Gilberto Camara <gilberto.camara.inpe@gmail.com>
Description: An end-to-end toolkit for land use and land cover classification
    using big Earth observation data. Builds satellite image data cubes from cloud collections.
    Supports visualization methods for images and time series and 
    smoothing filters for dealing with noisy time series.
    Enables merging of multi-source imagery (SAR, optical, DEM).
    Includes functions for quality assessment of training samples using self-organized maps and  
    to reduce training samples imbalance. Provides machine learning algorithms including support vector machines, 
    random forests, extreme gradient boosting, multi-layer perceptrons,
    temporal convolution neural networks, and temporal attention encoders.
    Performs efficient classification of big Earth observation data cubes and includes 
    functions for post-classification smoothing based on Bayesian inference. 
    Enables best practices for estimating area and assessing accuracy of land change. 
    Includes object-based spatio-temporal segmentation for space-time OBIA.
    Minimum recommended requirements: 16 GB RAM and 4 CPU dual-core.
Encoding: UTF-8
Language: en-US
Depends: R (>= 4.1.0)
URL: https://github.com/e-sensing/sits/,
        https://e-sensing.github.io/sitsbook/,
        https://e-sensing.github.io/sits/
BugReports: https://github.com/e-sensing/sits/issues
License: GPL-2
ByteCompile: true
LazyData: true
Imports: yaml (>= 2.3.0), dplyr (>= 1.1.0), grDevices, graphics, httr2
        (>= 1.1.0), leafgl, leaflet (>= 2.2.2), lubridate, luz (>=
        0.4.0), parallel, purrr (>= 1.0.2), randomForest, Rcpp (>=
        1.1.0), rstac (>= 1.0.1), sf (>= 1.0-19), slider (>= 0.2.0),
        stats, terra (>= 1.8-54), tibble (>= 3.3.0), tidyr (>= 1.3.0),
        tmap (>= 4.1), torch (>= 0.16.3), units, utils
Suggests: aws.s3, caret, cli, cols4all (>= 0.8.0), covr, dendextend,
        dtwclust, digest, e1071, exactextractr, FNN, gdalcubes (>=
        0.7.0), geojsonsf, ggplot2, jsonlite, kohonen (>= 3.0.11),
        lightgbm, methods, mgcv, nnet, openxlsx, parallelly, proxy,
        randomForestExplainer, RColorBrewer, RcppArmadillo (>= 14.0.0),
        scales, snic, spdep, stars, stringr, supercells (>= 1.0.0),
        testthat (>= 3.1.3), tools, xgboost
Config/testthat/edition: 3
Config/testthat/parallel: false
Config/testthat/start-first: cube, raster, regularize, data, ml
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 7.3.3
Collate: 'api_accessors.R' 'api_accuracy.R' 'api_apply.R' 'api_band.R'
        'api_bayts.R' 'api_bbox.R' 'api_block.R' 'api_check.R'
        'api_chunks.R' 'api_classify.R' 'api_clean.R' 'api_cluster.R'
        'api_colors.R' 'api_combine_predictions.R' 'api_comp.R'
        'api_conf.R' 'api_crop.R' 'api_csv.R' 'api_cube.R' 'api_data.R'
        'api_debug.R' 'api_detect_change.R' 'api_download.R'
        'api_dtw.R' 'api_environment.R' 'api_factory.R'
        'api_file_info.R' 'api_file.R' 'api_gdal.R' 'api_gdalcubes.R'
        'api_grid.R' 'api_jobs.R' 'api_kohonen.R' 'api_label_class.R'
        'api_mask.R' 'api_merge.R' 'api_mixture_model.R'
        'api_ml_model.R' 'api_message.R' 'api_mosaic.R'
        'api_opensearch.R' 'api_parallel.R' 'api_patterns.R'
        'api_period.R' 'api_plot_time_series.R' 'api_plot_raster.R'
        'api_plot_vector.R' 'api_point.R' 'api_predictors.R'
        'api_raster.R' 'api_reclassify.R' 'api_reduce.R'
        'api_regularize.R' 'api_request.R' 'api_request_httr2.R'
        'api_roi.R' 'api_samples.R' 'api_segments.R' 'api_select.R'
        'api_sf.R' 'api_shp.R' 'api_signal.R' 'api_smooth.R'
        'api_smote.R' 'api_som.R' 'api_source.R' 'api_source_aws.R'
        'api_source_bdc.R' 'api_source_cdse.R' 'api_source_cdse_os.R'
        'api_source_deafrica.R' 'api_source_deaustralia.R'
        'api_source_hls.R' 'api_source_local.R' 'api_source_mpc.R'
        'api_source_ogh.R' 'api_source_sdc.R' 'api_source_stac.R'
        'api_source_terrascope.R' 'api_source_usgs.R'
        'api_space_time_operations.R' 'api_stac.R' 'api_stats.R'
        'api_summary.R' 'api_texture.R' 'api_tibble.R' 'api_tile.R'
        'api_timeline.R' 'api_tmap.R' 'api_torch.R'
        'api_torch_psetae.R' 'api_ts.R' 'api_tuning.R'
        'api_uncertainty.R' 'api_utils.R' 'api_validate.R'
        'api_values.R' 'api_variance.R' 'api_vector.R'
        'api_vector_info.R' 'api_view.R' 'RcppExports.R' 'data.R'
        'sits-package.R' 'sits_add_base_cube.R' 'sits_apply.R'
        'sits_accuracy.R' 'sits_bands.R' 'sits_bayts.R' 'sits_bbox.R'
        'sits_classify.R' 'sits_colors.R' 'sits_combine_predictions.R'
        'sits_config.R' 'sits_csv.R' 'sits_cube.R' 'sits_cube_copy.R'
        'sits_cube_local.R' 'sits_clean.R' 'sits_cluster.R'
        'sits_detect_change.R' 'sits_detect_change_method.R'
        'sits_dtw.R' 'sits_factory.R' 'sits_filters.R'
        'sits_geo_dist.R' 'sits_get_data.R' 'sits_get_class.R'
        'sits_get_probs.R' 'sits_grid_systems.R' 'sits_histogram.R'
        'sits_imputation.R' 'sits_labels.R'
        'sits_label_classification.R' 'sits_lighttae.R'
        'sits_lstm_fcn.R' 'sits_machine_learning.R' 'sits_merge.R'
        'sits_mixture_model.R' 'sits_mlp.R' 'sits_mosaic.R'
        'sits_model_export.R' 'sits_patterns.R' 'sits_plot.R'
        'sits_predictors.R' 'sits_reclassify.R' 'sits_reduce.R'
        'sits_reduce_imbalance.R' 'sits_regularize.R' 'sits_resnet.R'
        'sits_sample_functions.R' 'sits_segmentation.R' 'sits_select.R'
        'sits_sf.R' 'sits_smooth.R' 'sits_som.R' 'sits_stars.R'
        'sits_summary.R' 'sits_tae.R' 'sits_tempcnn.R' 'sits_terra.R'
        'sits_texture.R' 'sits_timeline.R' 'sits_train.R'
        'sits_tuning.R' 'sits_utils.R' 'sits_uncertainty.R'
        'sits_validate.R' 'sits_view.R' 'sits_variance.R' 'sits_xlsx.R'
        'zzz.R'
NeedsCompilation: yes
Packaged: 2026-01-14 14:54:04 UTC; gilbertocamara
Author: Rolf Simoes [aut],
  Gilberto Camara [aut, cre, ths],
  Felipe Souza [aut],
  Felipe Carlos [aut],
  Lorena Santos [ctb],
  Charlotte Pelletier [ctb],
  Estefania Pizarro [ctb],
  Karine Ferreira [ctb, ths],
  Alber Sanchez [ctb],
  Alexandre Assuncao [ctb],
  Daniel Falbel [ctb],
  Gilberto Queiroz [ctb],
  Johannes Reiche [ctb],
  Pedro Andrade [ctb],
  Pedro Brito [ctb],
  Renato Assuncao [ctb],
  Ricardo Cartaxo [ctb]
Repository: CRAN
Date/Publication: 2026-01-14 15:30:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 13:25:19 UTC; unix
Archs: sits.so.dSYM
