# Generated by roxygen2: do not edit by hand

S3method(".tile_bands<-",raster_cube)
S3method(".tile_labels<-",raster_cube)
S3method(".tile_name<-",raster_cube)
S3method("sits_bands<-",default)
S3method("sits_bands<-",raster_cube)
S3method("sits_bands<-",sits)
S3method("sits_labels<-",class_cube)
S3method("sits_labels<-",class_vector_cube)
S3method("sits_labels<-",default)
S3method("sits_labels<-",probs_cube)
S3method("sits_labels<-",probs_vector_cube)
S3method("sits_labels<-",sits)
S3method(.accuracy_get_validation,csv)
S3method(.accuracy_get_validation,data.frame)
S3method(.accuracy_get_validation,gpkg)
S3method(.accuracy_get_validation,sf)
S3method(.accuracy_get_validation,shp)
S3method(.band_rename,raster_cube)
S3method(.band_rename,sits)
S3method(.check_samples,default)
S3method(.check_samples,sits)
S3method(.cube_adjust_crs,default)
S3method(.cube_adjust_crs,grd_cube)
S3method(.cube_area_freq,class_cube)
S3method(.cube_area_freq,class_vector_cube)
S3method(.cube_area_freq,default)
S3method(.cube_as_sf,default)
S3method(.cube_as_sf,raster_cube)
S3method(.cube_bands,default)
S3method(.cube_bands,raster_cube)
S3method(.cube_bands,tbl_df)
S3method(.cube_bbox,default)
S3method(.cube_bbox,raster_cube)
S3method(.cube_collection,default)
S3method(.cube_collection,raster_cube)
S3method(.cube_contains_cloud,default)
S3method(.cube_contains_cloud,raster_cube)
S3method(.cube_crs,default)
S3method(.cube_crs,raster_cube)
S3method(.cube_during,default)
S3method(.cube_during,raster_cube)
S3method(.cube_end_date,default)
S3method(.cube_end_date,raster_cube)
S3method(.cube_filter_bands,default)
S3method(.cube_filter_bands,raster_cube)
S3method(.cube_filter_dates,default)
S3method(.cube_filter_dates,raster_cube)
S3method(.cube_filter_interval,default)
S3method(.cube_filter_interval,raster_cube)
S3method(.cube_filter_spatial,default)
S3method(.cube_filter_spatial,raster_cube)
S3method(.cube_filter_tiles,default)
S3method(.cube_filter_tiles,raster_cube)
S3method(.cube_find_class,default)
S3method(.cube_find_class,raster_cube)
S3method(.cube_find_class,tbl_df)
S3method(.cube_geometry_use_s2,default)
S3method(.cube_geometry_use_s2,ogh_cube)
S3method(.cube_intersects,default)
S3method(.cube_intersects,raster_cube)
S3method(.cube_is_complete,default)
S3method(.cube_is_complete,raster_cube)
S3method(.cube_is_local,default)
S3method(.cube_is_local,raster_cube)
S3method(.cube_is_token_expired,default)
S3method(.cube_is_token_expired,mpc_cube)
S3method(.cube_labels,default)
S3method(.cube_labels,derived_cube)
S3method(.cube_labels,raster_cube)
S3method(.cube_labels,tbl_df)
S3method(.cube_merge_tiles,default)
S3method(.cube_merge_tiles,derived_cube)
S3method(.cube_merge_tiles,raster_cube)
S3method(.cube_ncols,default)
S3method(.cube_ncols,raster_cube)
S3method(.cube_nrows,default)
S3method(.cube_nrows,raster_cube)
S3method(.cube_paths,default)
S3method(.cube_paths,raster_cube)
S3method(.cube_period,default)
S3method(.cube_period,raster_cube)
S3method(.cube_s3class,default)
S3method(.cube_s3class,raster_cube)
S3method(.cube_source,default)
S3method(.cube_source,raster_cube)
S3method(.cube_split_assets,default)
S3method(.cube_split_assets,derived_cube)
S3method(.cube_split_assets,raster_cube)
S3method(.cube_split_features,default)
S3method(.cube_split_features,raster_cube)
S3method(.cube_start_date,default)
S3method(.cube_start_date,raster_cube)
S3method(.cube_tiles,default)
S3method(.cube_tiles,raster_cube)
S3method(.cube_timeline,default)
S3method(.cube_timeline,raster_cube)
S3method(.cube_timeline_acquisition,default)
S3method(.cube_timeline_acquisition,raster_cube)
S3method(.cube_token_flush,"terrascope_cube_world-cereal-2021")
S3method(.cube_token_flush,default)
S3method(.cube_token_generator,"terrascope_cube_world-cereal-2021")
S3method(.cube_token_generator,default)
S3method(.cube_token_generator,mpc_cube)
S3method(.cube_uses_gdal_auth,cdse_cube)
S3method(.cube_uses_gdal_auth,default)
S3method(.cube_uses_gdal_auth,hls_cube)
S3method(.data_get_ts,raster_cube)
S3method(.dc_bands,bayts_model)
S3method(.dc_bands,sits_model)
S3method(.detect_change_tile_prep,bayts_model)
S3method(.detect_change_tile_prep,default)
S3method(.gc_arrange_images,raster_cube)
S3method(.get_request,httr2)
S3method(.merge,dem_case)
S3method(.ml_normalize,default)
S3method(.ml_normalize,torch_model)
S3method(.mosaic_split_band_date,derived_cube)
S3method(.mosaic_split_band_date,raster_cube)
S3method(.opensearch_cdse_extract_tile,RTC)
S3method(.opensearch_cdse_search,RTC)
S3method(.predictors,sits)
S3method(.predictors,sits_base)
S3method(.reg_tile_convert,dem_cube)
S3method(.reg_tile_convert,grd_cube)
S3method(.reg_tile_convert,ogh_cube)
S3method(.reg_tile_convert,rainfall_cube)
S3method(.reg_tile_convert,raster_cube)
S3method(.reg_tile_convert,rtc_cube)
S3method(.request,httr2)
S3method(.request_check_package,httr2)
S3method(.request_headers,httr2)
S3method(.request_query,httr2)
S3method(.response_check_status,httr2)
S3method(.response_content,httr2)
S3method(.response_content_type,httr2)
S3method(.response_is_error,httr2)
S3method(.response_status,httr2)
S3method(.retry_request,httr2)
S3method(.samples_alloc_strata,class_cube)
S3method(.samples_alloc_strata,class_vector_cube)
S3method(.samples_bands,sits)
S3method(.samples_bands,sits_base)
S3method(.samples_select_bands,patterns)
S3method(.samples_select_bands,sits)
S3method(.samples_select_bands,sits_base)
S3method(.samples_select_dates,sits)
S3method(.samples_select_labels,sits)
S3method(.slice_dfr,numeric)
S3method(.source_collection_access_test,"mpc_cube_sentinel-1-grd")
S3method(.source_collection_access_test,cdse_cube)
S3method(.source_collection_access_test,cdse_os_cube)
S3method(.source_collection_access_test,hls_cube)
S3method(.source_collection_access_test,mpc_cube)
S3method(.source_collection_access_test,ogh_cube)
S3method(.source_collection_access_test,stac_cube)
S3method(.source_collection_access_test,usgs_cube)
S3method(.source_cube,stac_cube)
S3method(.source_filter_tiles,"cdse_os_cube_sentinel-1-rtc")
S3method(.source_filter_tiles,"deafrica_cube_sentinel-1-rtc")
S3method(.source_filter_tiles,"mpc_cube_cop-dem-glo-30")
S3method(.source_filter_tiles,"mpc_cube_sentinel-1-grd")
S3method(.source_filter_tiles,stac_cube)
S3method(.source_item_get_bands,stac_cube)
S3method(.source_item_get_cloud_cover,cdse_os_cube)
S3method(.source_item_get_cloud_cover,sdc_cube)
S3method(.source_item_get_cloud_cover,stac_cube)
S3method(.source_item_get_date,"mpc_cube_mod09a1-6.1")
S3method(.source_item_get_date,"mpc_cube_mod10a1-6.1")
S3method(.source_item_get_date,"mpc_cube_mod13q1-6.1")
S3method(.source_item_get_date,cdse_os_cube)
S3method(.source_item_get_date,deafrica_cube)
S3method(.source_item_get_date,stac_cube)
S3method(.source_item_get_hrefs,bdc_cube)
S3method(.source_item_get_hrefs,stac_cube)
S3method(.source_item_get_hrefs,usgs_cube)
S3method(.source_items_bands_select,cdse_os_cube)
S3method(.source_items_bands_select,stac_cube)
S3method(.source_items_cube,stac_cube)
S3method(.source_items_fid,stac_cube)
S3method(.source_items_new,"aws_cube_landsat-c2-l2")
S3method(.source_items_new,"deafrica_cube_sentinel-1-rtc")
S3method(.source_items_new,"deafrica_cube_sentinel-2-l2a")
S3method(.source_items_new,"mpc_cube_cop-dem-glo-30")
S3method(.source_items_new,"mpc_cube_landsat-c2-l2")
S3method(.source_items_new,"mpc_cube_sentinel-1-grd")
S3method(.source_items_new,"mpc_cube_sentinel-1-rtc")
S3method(.source_items_new,"mpc_cube_sentinel-2-l2a")
S3method(.source_items_new,"terrascope_cube_world-cereal-2021")
S3method(.source_items_new,"terrascope_cube_world-cover-2021")
S3method(.source_items_new,aws_cube)
S3method(.source_items_new,bdc_cube)
S3method(.source_items_new,cdse_cube)
S3method(.source_items_new,cdse_os_cube)
S3method(.source_items_new,deafrica_cube)
S3method(.source_items_new,deaustralia_cube)
S3method(.source_items_new,deaustralia_cube_ga_s2am_ard_3)
S3method(.source_items_new,deaustralia_cube_ga_s2bm_ard_3)
S3method(.source_items_new,hls_cube)
S3method(.source_items_new,mpc_cube)
S3method(.source_items_new,mpc_cube_hlsl30)
S3method(.source_items_new,mpc_cube_hlss30)
S3method(.source_items_new,ogh_cube)
S3method(.source_items_new,sdc_cube)
S3method(.source_items_new,usgs_cube)
S3method(.source_items_tile,"aws_cube_landsat-c2-l2")
S3method(.source_items_tile,"cdse_os_cube_sentinel-1-rtc")
S3method(.source_items_tile,"deafrica_cube_rainfall-chirps-daily")
S3method(.source_items_tile,"deafrica_cube_rainfall-chirps-monthly")
S3method(.source_items_tile,"mpc_cube_cop-dem-glo-30")
S3method(.source_items_tile,"mpc_cube_landsat-c2-l2")
S3method(.source_items_tile,"mpc_cube_mod09a1-6.1")
S3method(.source_items_tile,"mpc_cube_mod10a1-6.1")
S3method(.source_items_tile,"mpc_cube_mod13q1-6.1")
S3method(.source_items_tile,"mpc_cube_sentinel-1-grd")
S3method(.source_items_tile,"mpc_cube_sentinel-1-rtc")
S3method(.source_items_tile,"mpc_cube_sentinel-2-l2a")
S3method(.source_items_tile,"ogh_cube_landsat-glad-2m")
S3method(.source_items_tile,"terrascope_cube_world-cereal-2021")
S3method(.source_items_tile,"terrascope_cube_world-cover-2021")
S3method(.source_items_tile,aws_cube)
S3method(.source_items_tile,bdc_cube)
S3method(.source_items_tile,cdse_cube)
S3method(.source_items_tile,cdse_os_cube)
S3method(.source_items_tile,deafrica_cube)
S3method(.source_items_tile,deaustralia_cube)
S3method(.source_items_tile,hls_cube)
S3method(.source_items_tile,mpc_cube_hlsl30)
S3method(.source_items_tile,mpc_cube_hlss30)
S3method(.source_items_tile,sdc_cube)
S3method(.source_items_tile,usgs_cube)
S3method(.source_roi_tiles,"mpc_cube_landsat-c2-l2")
S3method(.source_roi_tiles,sdc_cube)
S3method(.source_roi_tiles,stac_cube)
S3method(.source_tile_get_bbox,"cdse_os_cube_sentinel-1-rtc")
S3method(.source_tile_get_bbox,"mpc_cube_cop-dem-glo-30")
S3method(.source_tile_get_bbox,"mpc_cube_sentinel-1-grd")
S3method(.source_tile_get_bbox,"mpc_cube_sentinel-1-rtc")
S3method(.source_tile_get_bbox,stac_cube)
S3method(.stac_static_link_filter,default)
S3method(.stac_static_link_filter,ogh)
S3method(.tile,default)
S3method(.tile,raster_cube)
S3method(.tile_area_freq,class_cube)
S3method(.tile_area_freq,class_vector_cube)
S3method(.tile_area_freq,default)
S3method(.tile_area_freq,raster_cube)
S3method(.tile_as_sf,default)
S3method(.tile_as_sf,raster_cube)
S3method(.tile_band_conf,default)
S3method(.tile_band_conf,derived_cube)
S3method(.tile_band_conf,eo_cube)
S3method(.tile_bands,base_raster_cube)
S3method(.tile_bands,default)
S3method(.tile_bands,raster_cube)
S3method(.tile_bbox,default)
S3method(.tile_bbox,raster_cube)
S3method(.tile_cloud_read_block,default)
S3method(.tile_cloud_read_block,eo_cube)
S3method(.tile_collection,default)
S3method(.tile_collection,raster_cube)
S3method(.tile_crs,default)
S3method(.tile_crs,raster_cube)
S3method(.tile_derived_class,derived_cube)
S3method(.tile_during,default)
S3method(.tile_during,raster_cube)
S3method(.tile_end_date,default)
S3method(.tile_end_date,raster_cube)
S3method(.tile_fid,default)
S3method(.tile_fid,raster_cube)
S3method(.tile_filter_bands,class_cube)
S3method(.tile_filter_bands,default)
S3method(.tile_filter_bands,derived_cube)
S3method(.tile_filter_bands,eo_cube)
S3method(.tile_filter_interval,default)
S3method(.tile_filter_interval,raster_cube)
S3method(.tile_from_file,default)
S3method(.tile_from_file,derived_cube)
S3method(.tile_from_file,eo_cube)
S3method(.tile_intersects,default)
S3method(.tile_intersects,raster_cube)
S3method(.tile_is_complete,default)
S3method(.tile_is_complete,raster_cube)
S3method(.tile_is_nonempty,default)
S3method(.tile_is_nonempty,raster_cube)
S3method(.tile_labels,default)
S3method(.tile_labels,raster_cube)
S3method(.tile_name,default)
S3method(.tile_name,raster_cube)
S3method(.tile_ncols,default)
S3method(.tile_ncols,raster_cube)
S3method(.tile_nrows,default)
S3method(.tile_nrows,raster_cube)
S3method(.tile_path,default)
S3method(.tile_path,derived_cube)
S3method(.tile_path,raster_cube)
S3method(.tile_paths,default)
S3method(.tile_paths,raster_cube)
S3method(.tile_period,default)
S3method(.tile_period,raster_cube)
S3method(.tile_read_block,class_cube)
S3method(.tile_read_block,default)
S3method(.tile_read_block,derived_cube)
S3method(.tile_read_block,eo_cube)
S3method(.tile_satellite,default)
S3method(.tile_satellite,raster_cube)
S3method(.tile_sensor,default)
S3method(.tile_sensor,raster_cube)
S3method(.tile_size,default)
S3method(.tile_size,raster_cube)
S3method(.tile_source,default)
S3method(.tile_source,raster_cube)
S3method(.tile_start_date,default)
S3method(.tile_start_date,raster_cube)
S3method(.tile_timeline,default)
S3method(.tile_timeline,raster_cube)
S3method(.tile_update_label,class_cube)
S3method(.tile_update_label,default)
S3method(.tile_within,default)
S3method(.tile_within,raster_cube)
S3method(.tile_xres,default)
S3method(.tile_xres,raster_cube)
S3method(.tile_yres,default)
S3method(.tile_yres,raster_cube)
S3method(.values_ts,bands_cases_dates)
S3method(.values_ts,bands_dates_cases)
S3method(.values_ts,cases_dates_bands)
S3method(.view_image_raster,bw)
S3method(.view_image_raster,rgb)
S3method(hist,probs_cube)
S3method(hist,raster_cube)
S3method(hist,sits)
S3method(hist,uncertainty_cube)
S3method(plot,class_cube)
S3method(plot,class_vector_cube)
S3method(plot,dem_cube)
S3method(plot,geo_distances)
S3method(plot,patterns)
S3method(plot,predicted)
S3method(plot,probs_cube)
S3method(plot,probs_vector_cube)
S3method(plot,raster_cube)
S3method(plot,rfor_model)
S3method(plot,sar_cube)
S3method(plot,sits)
S3method(plot,sits_accuracy)
S3method(plot,sits_cluster)
S3method(plot,sits_model)
S3method(plot,som_clean_samples)
S3method(plot,som_evaluate_cluster)
S3method(plot,som_map)
S3method(plot,torch_model)
S3method(plot,uncertainty_cube)
S3method(plot,uncertainty_vector_cube)
S3method(plot,variance_cube)
S3method(plot,vector_cube)
S3method(plot,xgb_model)
S3method(print,sits_accuracy)
S3method(print,sits_area_accuracy)
S3method(sits_accuracy,class_cube)
S3method(sits_accuracy,class_vector_cube)
S3method(sits_accuracy,default)
S3method(sits_accuracy,derived_cube)
S3method(sits_accuracy,raster_cube)
S3method(sits_accuracy,sits)
S3method(sits_accuracy,tbl_df)
S3method(sits_apply,default)
S3method(sits_apply,derived_cube)
S3method(sits_apply,raster_cube)
S3method(sits_apply,sits)
S3method(sits_as_sf,default)
S3method(sits_as_sf,raster_cube)
S3method(sits_as_sf,sits)
S3method(sits_as_sf,vector_cube)
S3method(sits_as_terra,class_cube)
S3method(sits_as_terra,probs_cube)
S3method(sits_as_terra,raster_cube)
S3method(sits_as_terra,uncertainty_cube)
S3method(sits_as_terra,variance_cube)
S3method(sits_bands,default)
S3method(sits_bands,patterns)
S3method(sits_bands,raster_cube)
S3method(sits_bands,sits)
S3method(sits_bands,sits_model)
S3method(sits_bbox,default)
S3method(sits_bbox,raster_cube)
S3method(sits_bbox,sits)
S3method(sits_bbox,tbl_df)
S3method(sits_classify,default)
S3method(sits_classify,derived_cube)
S3method(sits_classify,raster_cube)
S3method(sits_classify,sits)
S3method(sits_classify,tbl_df)
S3method(sits_classify,vector_cube)
S3method(sits_clean,class_cube)
S3method(sits_clean,default)
S3method(sits_clean,derived_cube)
S3method(sits_clean,raster_cube)
S3method(sits_colors_qgis,class_cube)
S3method(sits_colors_qgis,class_vector_cube)
S3method(sits_combine_predictions,average)
S3method(sits_combine_predictions,default)
S3method(sits_combine_predictions,uncertainty)
S3method(sits_cube,default)
S3method(sits_cube,local_cube)
S3method(sits_cube,results_cube)
S3method(sits_cube,stac_cube)
S3method(sits_cube,vector_cube)
S3method(sits_detect_change,default)
S3method(sits_detect_change,raster_cube)
S3method(sits_detect_change,sits)
S3method(sits_get_class,csv)
S3method(sits_get_class,data.frame)
S3method(sits_get_class,default)
S3method(sits_get_class,sf)
S3method(sits_get_class,shp)
S3method(sits_get_class,sits)
S3method(sits_get_data,csv)
S3method(sits_get_data,data.frame)
S3method(sits_get_data,default)
S3method(sits_get_data,sf)
S3method(sits_get_data,shp)
S3method(sits_get_data,sits)
S3method(sits_get_probs,csv)
S3method(sits_get_probs,data.frame)
S3method(sits_get_probs,default)
S3method(sits_get_probs,sf)
S3method(sits_get_probs,shp)
S3method(sits_get_probs,sits)
S3method(sits_label_classification,default)
S3method(sits_label_classification,derived_cube)
S3method(sits_label_classification,probs_cube)
S3method(sits_label_classification,probs_vector_cube)
S3method(sits_label_classification,raster_cube)
S3method(sits_labels,default)
S3method(sits_labels,derived_cube)
S3method(sits_labels,derived_vector_cube)
S3method(sits_labels,patterns)
S3method(sits_labels,raster_cube)
S3method(sits_labels,sits)
S3method(sits_labels,sits_model)
S3method(sits_labels_summary,sits)
S3method(sits_merge,default)
S3method(sits_merge,raster_cube)
S3method(sits_merge,sits)
S3method(sits_mixture_model,default)
S3method(sits_mixture_model,derived_cube)
S3method(sits_mixture_model,raster_cube)
S3method(sits_mixture_model,sits)
S3method(sits_mixture_model,tbl_df)
S3method(sits_model_export,sits_model)
S3method(sits_reclassify,class_cube)
S3method(sits_reclassify,default)
S3method(sits_reduce,raster_cube)
S3method(sits_reduce,sits)
S3method(sits_regularize,combined_cube)
S3method(sits_regularize,default)
S3method(sits_regularize,dem_cube)
S3method(sits_regularize,derived_cube)
S3method(sits_regularize,ogh_cube)
S3method(sits_regularize,rainfall_cube)
S3method(sits_regularize,raster_cube)
S3method(sits_regularize,sar_cube)
S3method(sits_select,default)
S3method(sits_select,raster_cube)
S3method(sits_select,sits)
S3method(sits_smooth,default)
S3method(sits_smooth,derived_cube)
S3method(sits_smooth,probs_cube)
S3method(sits_smooth,probs_vector_cube)
S3method(sits_smooth,raster_cube)
S3method(sits_texture,default)
S3method(sits_texture,derived_cube)
S3method(sits_texture,raster_cube)
S3method(sits_timeline,default)
S3method(sits_timeline,derived_cube)
S3method(sits_timeline,raster_cube)
S3method(sits_timeline,sits)
S3method(sits_timeline,sits_model)
S3method(sits_timeline,tbl_df)
S3method(sits_to_csv,default)
S3method(sits_to_csv,sits)
S3method(sits_to_csv,tbl_df)
S3method(sits_to_xlsx,list)
S3method(sits_to_xlsx,sits_accuracy)
S3method(sits_uncertainty,default)
S3method(sits_uncertainty,probs_cube)
S3method(sits_uncertainty,probs_vector_cube)
S3method(sits_uncertainty,raster_cube)
S3method(sits_variance,default)
S3method(sits_variance,derived_cube)
S3method(sits_variance,probs_cube)
S3method(sits_variance,raster_cube)
S3method(sits_view,class_cube)
S3method(sits_view,class_vector_cube)
S3method(sits_view,data.frame)
S3method(sits_view,default)
S3method(sits_view,probs_cube)
S3method(sits_view,raster_cube)
S3method(sits_view,sits)
S3method(sits_view,som_map)
S3method(sits_view,uncertainty_cube)
S3method(sits_view,vector_cube)
S3method(summary,class_cube)
S3method(summary,derived_cube)
S3method(summary,raster_cube)
S3method(summary,sits)
S3method(summary,sits_accuracy)
S3method(summary,sits_area_accuracy)
S3method(summary,variance_cube)
export("sits_bands<-")
export("sits_labels<-")
export(impute_linear)
export(impute_mean)
export(impute_mean_window)
export(impute_median)
export(sits_accuracy)
export(sits_accuracy_summary)
export(sits_add_base_cube)
export(sits_apply)
export(sits_as_sf)
export(sits_as_stars)
export(sits_as_terra)
export(sits_bands)
export(sits_bbox)
export(sits_classify)
export(sits_clean)
export(sits_cluster_clean)
export(sits_cluster_dendro)
export(sits_cluster_frequency)
export(sits_colors)
export(sits_colors_qgis)
export(sits_colors_reset)
export(sits_colors_set)
export(sits_colors_show)
export(sits_combine_predictions)
export(sits_confidence_sampling)
export(sits_config)
export(sits_config_show)
export(sits_config_user_file)
export(sits_cube)
export(sits_cube_copy)
export(sits_factory_function)
export(sits_filter)
export(sits_formula_linear)
export(sits_formula_logref)
export(sits_geo_dist)
export(sits_get_class)
export(sits_get_data)
export(sits_get_probs)
export(sits_impute)
export(sits_kfold_validate)
export(sits_label_classification)
export(sits_labels)
export(sits_labels_summary)
export(sits_lightgbm)
export(sits_lighttae)
export(sits_list_collections)
export(sits_merge)
export(sits_mgrs_to_roi)
export(sits_mixture_model)
export(sits_mlp)
export(sits_model_export)
export(sits_mosaic)
export(sits_patterns)
export(sits_pred_features)
export(sits_pred_normalize)
export(sits_pred_references)
export(sits_pred_sample)
export(sits_predictors)
export(sits_reclassify)
export(sits_reduce)
export(sits_reduce_imbalance)
export(sits_regularize)
export(sits_resnet)
export(sits_rfor)
export(sits_roi_to_mgrs)
export(sits_roi_to_tiles)
export(sits_run_examples)
export(sits_run_tests)
export(sits_sample)
export(sits_sampling_design)
export(sits_segment)
export(sits_select)
export(sits_sgolay)
export(sits_show_prediction)
export(sits_slic)
export(sits_smooth)
export(sits_snic)
export(sits_som_clean_samples)
export(sits_som_evaluate_cluster)
export(sits_som_map)
export(sits_som_remove_samples)
export(sits_stats)
export(sits_stratified_sampling)
export(sits_svm)
export(sits_tae)
export(sits_tempcnn)
export(sits_texture)
export(sits_tiles_to_roi)
export(sits_timeline)
export(sits_timeseries_to_csv)
export(sits_to_csv)
export(sits_to_xlsx)
export(sits_train)
export(sits_tuning)
export(sits_tuning_hparams)
export(sits_uncertainty)
export(sits_uncertainty_sampling)
export(sits_validate)
export(sits_variance)
export(sits_view)
export(sits_whittaker)
export(sits_xgboost)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,.data)
importFrom(lubridate,"%m+%")
importFrom(lubridate,"%within%")
importFrom(utils,download.file)
importFrom(utils,read.csv)
useDynLib(sits, .registration = TRUE)
